@@ -12,7 +12,7 @@
 #'        name(s) of the grouping factor(s), for which the repeatability should
 #'        be estimated. Spelling needs to match the random effect names as given in \code{formula} 
 #'        and terms have to be set in quotation marks. The reseved terms "Residual", 
-#'        "Overdispersion" and "Fixed" allow the estimation of oversipersion variance, residual 
+#'        "Overdispersion" and "Fixed" allow the estimation of overdispersion variance, residual 
 #'        variance and variance explained by fixed effects, respectively.
 #' @param data A dataframe that contains the variables included in the \code{formula}
 #'        and \code{grname} arguments.
@@ -151,28 +151,28 @@
 #' 
 #' @export
 #' 
-rpt <- function(formula, grname, data, datatype = c("Gaussian", "Binomial", "Proportion", 
+rpt <- function(formula, grname, data, datatype = c("Gaussian", "Binary", "Proportion", 
     "count"), link = c("logit", "probit", "log", "sqrt"), CI = 0.95, nboot = 1000, npermut = 0,
     parallel = FALSE, ncores = NULL, ratio = TRUE, adjusted = TRUE, expect = "meanobs",
     rptObj = NULL, update = FALSE) {
         
     if (datatype == "Gaussian") {
-            out_gaussian <- rptGaussian(formula, grname, data, CI, nboot, npermut, parallel, ncores, ratio, adjusted)
+            out_gaussian <- rptGaussian(formula, grname, data, CI, nboot, npermut, parallel, ncores, ratio, adjusted, rptObj, update)
             out_gaussian$call <- match.call()
             return(out_gaussian)
     }
     if (datatype == "Binary") {
-            out_binary <- rptBinary(formula, grname, data, link, CI, nboot, npermut, parallel, ncores, ratio, adjusted, expect)
+            out_binary <- rptBinary(formula, grname, data, link, CI, nboot, npermut, parallel, ncores, ratio, adjusted, expect, rptObj, update)
             out_binary$call <- match.call()
             return(out_binary)
     }
     if (datatype == "Proportion") {
-            out_proportion <- rptProportion(formula, grname, data, link, CI, nboot, npermut, parallel, ncores, ratio, adjusted, expect)
+            out_proportion <- rptProportion(formula, grname, data, link, CI, nboot, npermut, parallel, ncores, ratio, adjusted, expect, rptObj, update)
             out_proportion$call <- match.call()
             return(out_proportion)
     }
     if (datatype == "Poisson") {
-            out_poisson <- rptPoisson(formula, grname, data, link, CI, nboot, npermut, parallel, ncores, ratio, adjusted, expect)
+            out_poisson <- rptPoisson(formula, grname, data, link, CI, nboot, npermut, parallel, ncores, ratio, adjusted, expect, rptObj, update)
             out_poisson$call <- match.call()
             return(out_poisson)
     }
